@@ -329,9 +329,6 @@ action_bold_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
-	if (editor->priv->ignore_style_change)
-		return;
-
 	if (gtk_toggle_action_get_active (action))
 		command = "bold-on";
 	else
@@ -818,9 +815,6 @@ action_italic_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
-	if (editor->priv->ignore_style_change)
-		return;
-
 	if (gtk_toggle_action_get_active (action))
 		command = "italic-on";
 	else
@@ -988,9 +982,6 @@ action_monospaced_cb (GtkToggleAction *action,
 	GtkHTMLFontStyle and_mask;
 	GtkHTMLFontStyle or_mask;
 
-	if (editor->priv->ignore_style_change)
-		return;
-
 	if (gtk_toggle_action_get_active (action)) {
 		and_mask = GTK_HTML_FONT_STYLE_MAX;
 		or_mask = GTK_HTML_FONT_STYLE_FIXED;
@@ -1087,9 +1078,6 @@ action_style_cb (GtkRadioAction *action,
 {
 	const gchar *command = NULL;
 
-	if (editor->priv->ignore_style_change)
-		return;
-
 	switch (gtk_radio_action_get_current_value (current)) {
 		case GTK_HTML_PARAGRAPH_STYLE_NORMAL:
 			command = "style-normal";
@@ -1176,9 +1164,6 @@ action_size_cb (GtkRadioAction *action,
 {
 	const gchar *command = NULL;
 
-	if (editor->priv->ignore_style_change)
-		return;
-
 	switch (gtk_radio_action_get_current_value (current)) {
 		case GTK_HTML_FONT_STYLE_SIZE_1:
 			command = "size-minus-2";
@@ -1219,9 +1204,6 @@ action_strikethrough_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
-	if (editor->priv->ignore_style_change)
-		return;
-
 	if (gtk_toggle_action_get_active (action))
 		command = "strikeout-on";
 	else
@@ -1249,9 +1231,6 @@ action_underline_cb (GtkToggleAction *action,
 {
 	const gchar *command;
 
-	if (editor->priv->ignore_style_change)
-		return;
-
 	if (gtk_toggle_action_get_active (action))
 		command = "underline-on";
 	else
@@ -2174,6 +2153,15 @@ static GtkActionEntry spell_context_entries[] = {
 	  N_("Add Word To"),
 	  NULL,
 	  NULL,
+	  NULL },
+
+	/* Menus */
+
+	{ "context-more-suggestions-menu",
+	  NULL,
+	  N_("More Suggestions"),
+	  NULL,
+	  NULL,
 	  NULL }
 };
 
